@@ -17,9 +17,9 @@
 #' @examples
 #' # Case 1. vector example
 #' 
-#' x <- c(9.5, 12, 12.3, 17)
+#' x = c(9.5, 12, 12.3, 17)
 #' 
-#' y <- 11.2
+#' y = 11.2
 #' 
 #' reliability(x, y)
 #' 
@@ -27,15 +27,15 @@
 #' 
 #' library("PlackettLuce") 
 #' 
-#' R <- matrix(c(1, 2, 4, 3,
+#' R = matrix(c(1, 2, 4, 3,
 #'               4, 1, 2, 3,
 #'               2, 3, 1, 4,
 #'               4, 2, 3, 1,
 #'               2, 1, 4, 3,
 #'               1, 4, 3, 2), nrow = 6, byrow = TRUE)
-#' colnames(R) <- c("apple", "banana", "orange", "pear")
+#' colnames(R) = c("apple", "banana", "orange", "pear")
 #' 
-#' mod <- PlackettLuce(R)
+#' mod = PlackettLuce(R)
 #' 
 #' reliability(mod, ref = "orange")
 #' 
@@ -44,15 +44,15 @@
 #' 
 #' data("beans", package = "PlackettLuce")
 #' 
-#' G <- rank_tricot(data = beans,
+#' G = rank_tricot(data = beans,
 #'                  items = c(1:3),
 #'                  input = c(4:5),
 #'                  group = TRUE,
 #'                  additional.rank = beans[c(6:8)])
 #' 
-#' pld <- cbind(G, beans[,c("maxTN", "season", "lon")])
+#' pld = cbind(G, beans[,c("maxTN", "season", "lon")])
 #' 
-#' tree <- pltree(G ~ maxTN + season + lon, data = pld)
+#' tree = pltree(G ~ maxTN + season + lon, data = pld)
 #' 
 #' reliability(tree, ref = "Local")
 #' 
@@ -61,28 +61,28 @@
 #' @importFrom qvcalc qvcalc
 #' @importFrom stats update pnorm
 #' @export
-reliability <- function(x, ...) {
-    
+reliability = function(x, ...) {
+  
   UseMethod("reliability")
   
 }
 
 #' @rdname reliability
 #' @export
-reliability.default <- function(x, y = NULL, ...) {
+reliability.default = function(x, y = NULL, ...) {
   
-  dots <- list(...)
-
-  ref <- dots[["ref"]]
+  dots = list(...)
   
-  worth <- x
+  ref = dots[["ref"]]
+  
+  worth = x
   
   if (is.null(ref)) {
-    ref_worth <- y
+    ref_worth = y
   }
   
   if (is.null(y)) {
-    ref_worth <- worth[ref]
+    ref_worth = worth[ref]
   }
   
   worth / (ref_worth + worth)
@@ -92,47 +92,47 @@ reliability.default <- function(x, y = NULL, ...) {
 #' @rdname reliability
 #' @method reliability PlackettLuce
 #' @export
-reliability.PlackettLuce <- function(x, ref, ...) {
+reliability.PlackettLuce = function(x, ref, ...) {
   
-  x <- qvcalc::qvcalc(x, ref = ref)$qvframe
+  x = qvcalc::qvcalc(x, ref = ref)$qvframe
   
-  items <- rownames(x)
+  items = rownames(x)
   
-  whichref <- which(items %in% ref)
+  whichref = which(items %in% ref)
   
-  worth <- exp(x$estimate) / sum(exp(x$estimate)) 
+  worth = exp(x$estimate) / sum(exp(x$estimate)) 
   
-  rel <- worth / (worth[whichref] + worth)
+  rel = worth / (worth[whichref] + worth)
   
-  x$reliability <- rel
+  x$reliability = rel
   
-  rel_upper <- (exp(log(worth) + x$quasiSE) / (worth[whichref] + exp(log(worth) + x$quasiSE)))  
+  rel_upper = (exp(log(worth) + x$quasiSE) / (worth[whichref] + exp(log(worth) + x$quasiSE)))  
   
-  rel_lower <- (exp(log(worth) - x$quasiSE) / (worth[whichref] + exp(log(worth) - x$quasiSE)))  
+  rel_lower = (exp(log(worth) - x$quasiSE) / (worth[whichref] + exp(log(worth) - x$quasiSE)))  
   
-  rel_se <-  rel - rel_lower
-
-  x$rel_se <- rel_se
+  rel_se =  rel - rel_lower
   
-  x$worth <- worth
+  x$rel_se = rel_se
+  
+  x$worth = worth
   
   # #formulas from summary Plackett-Luce package
   # #https://github.com/hturner/PlackettLuce/blob/master/R/summary.R
-  x$Z <- x$estimate/x$SE
-
-  x$p_value <- 2 * stats::pnorm(-abs(x$Z))
+  x$Z = x$estimate/x$SE
   
-  x$item <- rownames(x)
+  x$p_value = 2 * stats::pnorm(-abs(x$Z))
   
-  x <- x[,c("item", "reliability", "rel_se","worth", "Z", "p_value")]
+  x$item = rownames(x)
   
-  x[is.na(x)] <- NA
+  x = x[,c("item", "reliability", "rel_se","worth", "Z", "p_value")]
   
-  rownames(x) <- 1:nrow(x)
+  x[is.na(x)] = NA
   
-  names(x) <- c("item", "reliability", "reliabilitySE", "worth", "Zvalue", "Pr(>|z|)")
+  rownames(x) = 1:nrow(x)
   
-  class(x) <- union("gosset_df", class(x))
+  names(x) = c("item", "reliability", "reliabilitySE", "worth", "Zvalue", "Pr(>|z|)")
+  
+  class(x) = union("gosset_df", class(x))
   
   return(x)
   
@@ -141,32 +141,32 @@ reliability.PlackettLuce <- function(x, ref, ...) {
 #' @rdname reliability
 #' @method reliability pltree
 #' @export 
-reliability.pltree <- function(x, ref, ...) {
+reliability.pltree = function(x, ref, ...) {
   
   # Extract ids from terminal nodes
-  node_id <- partykit::nodeids(x, terminal = TRUE)
+  node_id = partykit::nodeids(x, terminal = TRUE)
   
   # get models from each node
-  nodes <- list()
+  nodes = list()
   for (i in seq_along(node_id)) {
-    mod_i <- x[[ node_id[i] ]]$node$info$object
-    # r <- mod_i$rankings
-    # r <- pseudo_rank(r)
-    # mod_i <- stats::update(mod_i, rankings = r)
-    nodes[[i]] <- mod_i
+    mod_i = x[[ node_id[i] ]]$node$info$object
+    # r = mod_i$rankings
+    # r = pseudo_rank(r)
+    # mod_i = stats::update(mod_i, rankings = r)
+    nodes[[i]] = mod_i
   }
   
-  rel <- lapply(nodes, function(y){
+  rel = lapply(nodes, function(y){
     reliability.PlackettLuce(y, ref = ref)
   })
   
-  nitems <- nrow(rel[[1]])
+  nitems = nrow(rel[[1]])
   
-  rel <- do.call("rbind", rel)
+  rel = do.call("rbind", rel)
   
-  rel <- cbind(node = rep(node_id, each = nitems), rel)
+  rel = cbind(node = rep(node_id, each = nitems), rel)
   
-  class(rel) <- union("gosset_df", class(rel))
+  class(rel) = union("gosset_df", class(rel))
   
   return(rel)
   
